aboutsummaryrefslogtreecommitdiff
path: root/tun/wintun/setupapi
diff options
context:
space:
mode:
Diffstat (limited to 'tun/wintun/setupapi')
-rw-r--r--tun/wintun/setupapi/types_windows.go4
1 files changed, 2 insertions, 2 deletions
diff --git a/tun/wintun/setupapi/types_windows.go b/tun/wintun/setupapi/types_windows.go
index 7994f3c..c024b11 100644
--- a/tun/wintun/setupapi/types_windows.go
+++ b/tun/wintun/setupapi/types_windows.go
@@ -284,8 +284,8 @@ const (
DI_REMOVEDEVICE_CONFIGSPECIFIC DI_REMOVEDEVICE = 0x00000002 // Make this change to only the hardware profile specified by HwProfile. this flag only applies to root-enumerated devices. When Windows removes the device from the last hardware profile in which it was configured, Windows performs a global removal.
)
-// SP_REMOVEDEVICE_PARAMS is a structure corresponding to a DIF_REMOVE install function.
-type SP_REMOVEDEVICE_PARAMS struct {
+// RemoveDeviceParams is a structure corresponding to a DIF_REMOVE install function.
+type RemoveDeviceParams struct {
ClassInstallHeader ClassInstallHeader
Scope DI_REMOVEDEVICE
HwProfile uint32